<?php
/**
 * fPortfolio functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 *
 * @subpackage fPortfolio
 * @author tishonator
 * @since fPortfolio 1.0.0
 *
 */

require_once( trailingslashit( get_template_directory() ) . 'customize-pro/class-customize.php' );

if ( ! function_exists( 'fportfolio_setup' ) ) :
/**
 * fPortfolio setup.
 *
 * Set up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support post thumbnails.
 *
 */
function fportfolio_setup() {

	load_theme_textdomain( 'fportfolio', get_template_directory() . '/languages' );

	add_theme_support( "title-tag" );

	// add the visual editor to resemble the theme style
	add_editor_style( array( 'css/editor-style.css', get_template_directory_uri() . '/css/font-awesome.min.css' ) );

	// This theme uses wp_nav_menu() in two locations.
	register_nav_menus( array(
		'primary'   => __( 'Primary Menu', 'fportfolio' ),
	) );

	// add Custom background				 
	add_theme_support( 'custom-background', 
				   array ('default-color'  => '#FFFFFF')
				 );

	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 1200, 0, true );

	global $content_width;
	if ( ! isset( $content_width ) )
		$content_width = 900;

	add_theme_support( 'automatic-feed-links' );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'comment-form', 'comment-list',
	) );

	// add custom header
    add_theme_support( 'custom-header', array (
                       'default-image'          => '',
                       'random-default'         => '',
                       'flex-height'            => true,
                       'flex-width'             => true,
                       'uploads'                => true,
                       'width'                  => 900,
                       'height'                 => 100,
                       'default-text-color'     => '#000000',
                       'wp-head-callback'       => 'fportfolio_header_style',
                    ) );

    // add custom logo
    add_theme_support( 'custom-logo', array (
                       'width'                  => 145,
                       'height'                 => 36,
                       'flex-height'            => true,
                       'flex-width'             => true,
                    ) );
}
endif; // fportfolio_setup
add_action( 'after_setup_theme', 'fportfolio_setup' );

/**
 * the main function to load scripts in the fPortfolio theme
 * if you add a new load of script, style, etc. you can use that function
 * instead of adding a new wp_enqueue_scripts action for it.
 */
function fportfolio_load_scripts() {

	// load main stylesheet.
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array( ) );
	wp_enqueue_style( 'fportfolio-style', get_stylesheet_uri(), array() );
	
	wp_enqueue_style( 'fportfolio-fonts', fportfolio_fonts_url(), array(), null );
	
	// Load thread comments reply script
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
        wp_enqueue_script( 'comment-reply' );
    }
	
	// Load Utilities JS Script
	wp_enqueue_script( 'fportfolio-js', get_template_directory_uri() . '/js/fportfolio.js', array( 'jquery' ) );

	wp_enqueue_script( 'jquery.resize', get_template_directory_uri() . '/js/jquery.resize.js', array( 'jquery' ) );
	wp_enqueue_script( 'jquery.waitforimages', get_template_directory_uri() . '/js/jquery.waitforimages.js', array( 'jquery' ) );
	wp_enqueue_script( 'modernizr', get_template_directory_uri() . '/js/modernizr.js', array( 'jquery' ) );
	wp_enqueue_script( 'jquery.carousel-3d', get_template_directory_uri() . '/js/jquery.carousel-3d.min.js', array( 'jquery' ) );
}

add_action( 'wp_enqueue_scripts', 'fportfolio_load_scripts' );

/**
 *	Load google font url used in the fPortfolio theme
 */
function fportfolio_fonts_url() {

    $fonts_url = '';
 
    /* Translators: If there are characters in your language that are not
    * supported by PT Sans, translate this to 'off'. Do not translate
    * into your own language.
    */
    $cantarell = _x( 'on', 'Varela Round font: on or off', 'fportfolio' );

    if ( 'off' !== $cantarell ) {
        $font_families = array();
 
        $font_families[] = 'Varela Round';
 
        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );
 
        $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
    }
 
    return $fonts_url;
}

/**
 * Display website's logo image
 */
function fportfolio_show_website_logo_image_and_title() {

	if ( has_custom_logo() ) {

        the_custom_logo();
    }

    $header_text_color = get_header_textcolor();

    if ( 'blank' !== $header_text_color ) {
    
        echo '<div id="site-identity">';
        echo '<a href="' . esc_url( home_url('/') ) . '" title="' . esc_attr( get_bloginfo('name') ) . '">';
        echo '<h1>'.get_bloginfo('name').'</h1>';
        echo '</a>';
        echo '<strong>'.get_bloginfo('description').'</strong>';
        echo '</div>';
    }
}

/**
 *	Displays the copyright text.
 */
function fportfolio_show_copyright_text() {

	$footerText = get_theme_mod('fportfolio_footer_copyright', null);

	if ( !empty( $footerText ) ) {

		echo esc_html( $footerText ) . ' | ';		
	}
}

/**
 *	widgets-init action handler. Used to register widgets and register widget areas
 */
function fportfolio_widgets_init() {
	
	// Register Sidebar Widget.
	register_sidebar( array (
						'name'	 		 =>	 __( 'Sidebar Widget Area', 'fportfolio'),
						'id'		 	 =>	 'sidebar-widget-area',
						'description'	 =>  __( 'The sidebar widget area', 'fportfolio'),
						'before_widget'	 =>  '',
						'after_widget'	 =>  '',
						'before_title'	 =>  '<div class="sidebar-before-title"></div><h3 class="sidebar-title">',
						'after_title'	 =>  '</h3><div class="sidebar-after-title"></div>',
					) );

	// Register Footer Column #1
	register_sidebar( array (
							'name'			 =>  __( 'Footer Column #1', 'fportfolio' ),
							'id' 			 =>  'footer-column-1-widget-area',
							'description'	 =>  __( 'The Footer Column #1 widget area', 'fportfolio' ),
							'before_widget'  =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<h2 class="footer-title">',
							'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
						) );
	
	// Register Footer Column #2
	register_sidebar( array (
							'name'			 =>  __( 'Footer Column #2', 'fportfolio' ),
							'id' 			 =>  'footer-column-2-widget-area',
							'description'	 =>  __( 'The Footer Column #2 widget area', 'fportfolio' ),
							'before_widget'  =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<h2 class="footer-title">',
							'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
						) );
	
	// Register Footer Column #3
	register_sidebar( array (
							'name'			 =>  __( 'Footer Column #3', 'fportfolio' ),
							'id' 			 =>  'footer-column-3-widget-area',
							'description'	 =>  __( 'The Footer Column #3 widget area', 'fportfolio' ),
							'before_widget'  =>  '',
							'after_widget'	 =>  '',
							'before_title'	 =>  '<h2 class="footer-title">',
							'after_title'	 =>  '</h2><div class="footer-after-title"></div>',
						) );
}

add_action( 'widgets_init', 'fportfolio_widgets_init' );

function fportfolio_shoild_display_slider() {

	$result = false;
	for ( $i = 1; $i <= 5; ++$i ) {

		$defaultSlideImage = get_template_directory_uri().'/images/slider/' . $i .'.jpg';
		$slideImage = get_theme_mod( 'fportfolio_slide'.$i.'_image', $defaultSlideImage );
			
		if ($slideImage != '') {

			$result = true;
			break;
		}
	}

	return $result;
}

/**
 * Displays the slider
 */
function fportfolio_display_slider() {

	if ( !fportfolio_shoild_display_slider() ) {
		return;
	}

	?>

	 <div data-carousel-3d="true">
		<?php
			// display slides
			for ( $i = 1; $i <= 5; ++$i ) {
					
					$defaultSlideImage = get_template_directory_uri().'/images/slider/' . $i .'.jpg';
					$slideImage = get_theme_mod( 'fportfolio_slide'.$i.'_image', $defaultSlideImage );
				?>		
					<?php if ($slideImage != '') : ?>
							<div class="slide" style="background-image: url('<?php echo esc_url( $slideImage ); ?>');">
							</div>
					<?php endif; ?>
<?php		} ?>
	</div><!-- [data-carousel-3d] -->
<?php 
}

function fportfolio_p_link( $i, $title = '' ) {

	if ( $title == '' ) {
		$title = sprintf( __('Page %s', 'fportfolio'), $i );
	}
	
	echo "<a class='page-numbers' href='", esc_url( get_pagenum_link( $i ) ), "' title='", esc_attr($title), "'>{$i}</a>";
}

/**
 * Register theme settings in the customizer
 */
function fportfolio_customize_register( $wp_customize ) {
	
	/**
	 * Add Slider Section
	 */
	$wp_customize->add_section(
		'fportfolio_slider_section',
		array(
			'title'       => __( 'Slider', 'fportfolio' ),
			'capability'  => 'edit_theme_options',
		)
	);

	// Add slide 1 background image
	$wp_customize->add_setting( 'fportfolio_slide1_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '1.jpg',
    		'sanitize_callback' => 'esc_url_raw'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fportfolio_slide1_image',
			array(
				'label'   	 => __( 'Slide 1 Image', 'fportfolio' ),
				'section' 	 => 'fportfolio_slider_section',
				'settings'   => 'fportfolio_slide1_image',
			) 
		)
	);
	
	// Add slide 2 background image
	$wp_customize->add_setting( 'fportfolio_slide2_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '2.jpg',
    		'sanitize_callback' => 'esc_url_raw'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fportfolio_slide2_image',
			array(
				'label'   	 => __( 'Slide 2 Image', 'fportfolio' ),
				'section' 	 => 'fportfolio_slider_section',
				'settings'   => 'fportfolio_slide2_image',
			) 
		)
	);
	
	// Add slide 3 background image
	$wp_customize->add_setting( 'fportfolio_slide3_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '3.jpg',
    		'sanitize_callback' => 'esc_url_raw'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fportfolio_slide3_image',
			array(
				'label'   	 => __( 'Slide 3 Image', 'fportfolio' ),
				'section' 	 => 'fportfolio_slider_section',
				'settings'   => 'fportfolio_slide3_image',
			) 
		)
	);
	
	// Add slide 4 background image
	$wp_customize->add_setting( 'fportfolio_slide4_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '4.jpg',
    		'sanitize_callback' => 'esc_url_raw'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fportfolio_slide4_image',
			array(
				'label'   	 => __( 'Slide 4 Image', 'fportfolio' ),
				'section' 	 => 'fportfolio_slider_section',
				'settings'   => 'fportfolio_slide4_image',
			) 
		)
	);
	
	// Add slide 5 background image
	$wp_customize->add_setting( 'fportfolio_slide5_image',
		array(
			'default' => get_template_directory_uri().'/images/slider/' . '5.jpg',
    		'sanitize_callback' => 'esc_url_raw'
		)
	);

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fportfolio_slide5_image',
			array(
				'label'   	 => __( 'Slide 5 Image', 'fportfolio' ),
				'section' 	 => 'fportfolio_slider_section',
				'settings'   => 'fportfolio_slide5_image',
			) 
		)
	);

	/**
	 * Add Footer Section
	 */
	$wp_customize->add_section(
		'fportfolio_footer_section',
		array(
			'title'       => __( 'Footer', 'fportfolio' ),
			'capability'  => 'edit_theme_options',
		)
	);
	
	// Add footer copyright text
	$wp_customize->add_setting(
		'fportfolio_footer_copyright',
		array(
		    'default'           => '',
		    'sanitize_callback' => 'sanitize_text_field',
		)
	);

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'fportfolio_footer_copyright',
        array(
            'label'          => __( 'Copyright Text', 'fportfolio' ),
            'section'        => 'fportfolio_footer_section',
            'settings'       => 'fportfolio_footer_copyright',
            'type'           => 'text',
            )
        )
	);
}

add_action('customize_register', 'fportfolio_customize_register');

function fportfolio_header_style() {

    $header_text_color = get_header_textcolor();

    if ( ! has_header_image()
        && ( get_theme_support( 'custom-header', 'default-text-color' ) === $header_text_color
             || 'blank' === $header_text_color ) ) {

        return;
    }

    $headerImage = get_header_image();
?>
    <style type="text/css">
        <?php if ( has_header_image() ) : ?>

                #header-main-fixed {background-image: url("<?php echo esc_attr( $headerImage ); ?>");}

        <?php endif; ?>

        <?php if ( get_theme_support( 'custom-header', 'default-text-color' ) !== $header_text_color
                    && 'blank' !== $header_text_color ) : ?>

                #header-main-fixed {color: #<?php echo esc_attr( $header_text_color ); ?>;}

        <?php endif; ?>
    </style>
<?php

}

?>
